@@ -1,4 +1,4 @@
-## Copyright (C) 2013 Philip Nienhuis
+## Copyright (C) 2013-2015 Philip Nienhuis
 ## 
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -32,6 +32,7 @@
 ## 2013-11-15 Replace slow xml node parsing by regexp a la Markus Bergholz
 ## 2014-02-20 Add ValueFormat tag to regexp pattern
 ## 2014-04-13 Fix regexp patterns
+## 2015-03-07 Replace deprecated strmatch
 
 function [ rawarr, xls, rstatus] = __OCT_gnm2oct__ (xls, wsh, cellrange='', spsh_opts)
 
@@ -43,7 +44,7 @@ function [ rawarr, xls, rstatus] = __OCT_gnm2oct__ (xls, wsh, cellrange='', spsh
       error ("xls2oct: sheet number (%d) out of range (1 - %d)", wsh, numel (xls.sheets.sh_names));
     endif
   elseif (ischar (wsh))
-    idx = strmatch (wsh, xls.sheets.sh_names);
+    idx = find (strcmp (wsh, xls.sheets.sh_names));
     if (isempty (idx))
       error ("xls2oct: sheet '%s' not found in file %s", wsh, xls.filename);
     endif
