@@ -1,4 +1,4 @@
-## Copyright (C) 2009,2010,2011,2012,2013,2014 Philip Nienhuis
+## Copyright (C) 2009-2015 Philip Nienhuis
 ##
 ## This program is free software; you can redistribute it and/or modify it under
 ## the terms of the GNU General Public License as published by the Free Software
@@ -18,29 +18,31 @@
 ## @deftypefnx {Function File} [@var{xls}] = xlsclose (@var{xls}, @var{filename})
 ## @deftypefnx {Function File} [@var{xls}] = xlsclose (@var{xls}, "FORCE")
 ## Close the Excel spreadsheet pointed to in struct @var{xls}, if needed
-## write the file to disk. Based on information contained in @var{xls},
+## write the file to disk.  Based on information contained in @var{xls},
 ## xlsclose will determine if the file should be written to disk.
 ##
 ## If no errors occured during writing, the xls file pointer struct will be
 ## reset and -if COM interface was used- ActiveX/Excel will be closed.
-## However if errors occurred, the file pinter will be untouched so you can
+## However if errors occurred, the file pointer will be untouched so you can
 ## clean up before a next try with xlsclose().
 ## Be warned that until xlsopen is called again with the same @var{xls} pointer
 ## struct, hidden Excel or Java applications with associated (possibly large)
 ## memory chunks are kept in memory, taking up resources.
 ## If (string) argument "FORCE" is supplied, the file pointer will be reset 
 ## regardless, whether the possibly modified file has been saved successfully
-## or not. Hidden Excel (COM) or OpenOffice.org (UNO) invocations may live on,
+## or not.  Hidden Excel (COM) or OpenOffice.org (UNO) invocations may live on,
 ## possibly even impeding proper shutdown of Octave.
 ##
 ## @var{filename} can be used to write changed spreadsheet files to
 ## an other file than opened with xlsopen(); unfortunately this doesn't work
 ## with JXL (JExcelAPI) interface.
 ##
-## For other file formats than OOXML and ODS, you need MS-Excel (95 - 2010),
-## and/or the Java package => 1.2.8 plus Apache POI > 3.5 and/or JExcelAPI
-## and/or OpenXLS and/or OpenOffice.org or clones installed on your computer
-## + proper javaclasspath set, to make this function work at all.
+## For other file formats than OOXML, ODS or gnumeric, you need MS-Excel
+## (95 - 2010), and/or the Java package => 1.2.8 plus Apache POI > 3.5 and/or
+## JExcelAPI and/or OpenXLS and/or OpenOffice.org or clones installed on your
+## computer + proper javaclasspath set, to make this function work at all.
+## For Octave >= 3.8.0 the Java package isn't needed as Java support should
+## be built-in.
 ##
 ## @var{xls} must be a valid pointer struct made by xlsopen() in the same
 ## octave session.
@@ -84,6 +86,7 @@
 ## 2014-01-01 Style fixes
 ## 2014-04-13 Updated copyright strings
 ## 2014-04-26 Fix error messages (no more traceback)
+## 2015-03-06 Fix typos etc. in texinfo header
 
 function [ xls ] = xlsclose (xls, varargs)
 
