@@ -1,4 +1,4 @@
-## Copyright (C) 2009,2010,2011,2012,2013,2014 Philip Nienhuis
+## Copyright (C) 2009-2015 Philip Nienhuis
 ## 
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -40,12 +40,13 @@
 ## Excel'95 spreadsheets (BIFF5) can only be read using the COM (Excel-ActiveX),
 ## JXL (JExcelAPI), and UNO (Open-/LibreOffice) interfaces.
 ##
-## @var{filename} should be a valid .xls or xlsx Excel file name (including
+## @var{filename} should be a valid .xls or .xlsx Excel file name (including
 ## extension). But if you use the COM interface you can specify any extension
 ## that your installed Excel version can read AND write; the same goes for UNO
 ## (OpenOffice.org). Using the other Java interfaces, only .xls or .xlsx are
 ## allowed. If @var{filename} does not contain any directory path, the file
-## is saved in the current directory.
+## is saved in the current directory.  Reading/writing .xlsm and .xlsb files
+## may be possible using the COM and UNO interfaces only, but is untested.
 ##
 ## If @var{readwrite} is set to 0 (default value) or omitted, the spreadsheet
 ## file is opened for reading. If @var{readwrite} is set to true or 1, a
@@ -142,6 +143,10 @@
 ## 2014-04-13 Updated texinfo header
 ## 2014-04-26 Fix error messages (no more traceback)
 ## 2014-04-30 Allow gnumeric write support (remove catch)
+## 2015-02-15 Remove gnumeric debug comments
+##     ''     Clarify message about missing I/O support with file extension
+## 2015-03-06 Clarify some error messages, replace usage() with error
+##     ''     Be silent when creating new file
 
 function [ xls ] = xlsopen (filename, xwrite=0, reqinterface=[])
 
@@ -159,16 +164,16 @@ function [ xls ] = xlsopen (filename, xwrite=0, reqinterface=[])
   xlssupport = 0;
 
   if (nargout < 1)
-      usage ("XLS = xlsopen (Xlfile [, Rw] [, reqintf]). But no return argument specified!"); 
+      error ("xlsopen.m: no return argument specified!\n usage:  XLS = xlsopen (Xlfile [, Rw] [, reqintf])\n"); 
   endif
 
   if (! (islogical (xwrite) || isnumeric (xwrite)))
-      usage ("xlsopen.m: numerical or logical value expected for arg ## 2 (readwrite)")
+      error ("xlsopen.m: numerical or logical value expected for arg ## 2 (readwrite)\n")
   endif
 
   if (! isempty (reqinterface))
     if (! (ischar (reqinterface) || iscell (reqinterface)))
-      usage ("Arg ## 3 (interface) not recognized - character value required"); 
+      error ("Arg ## 3 (interface) not recognized - character value required\n"); 
     endif
     ## Turn arg3 into cell array if needed
     if (! iscell (reqinterface))
@@ -197,7 +202,7 @@ function [ xls ] = xlsopen (filename, xwrite=0, reqinterface=[])
         elseif (strcmpi (reqintf, 'OCT'))
           xlsinterfaces.OCT = [];
         else 
-          usage (sprintf (["xlsopen.m: unknown .xls interface \"%s\" requested.\n" 
+          error (sprintf (["xlsopen.m: unknown .xls interface \"%s\" requested.\n" 
                  "Only COM, POI, JXL, OXS, UNO, or OCT) supported\n"], reqinterface{}));
         endif
       endfor
@@ -258,14 +263,11 @@ function [ xls ] = xlsopen (filename, xwrite=0, reqinterface=[])
   
   ## Adapt file open mode for readwrite argument
   if (xwrite)
-%    ## Catch attempts to write gnumeric
-%    if (ftype == 5)
-%      error ("xlsopen: there's only read support for gnumeric files\n");
-%    endif
     fmode = 'r+b';
     if (! has_suffix)
       ## Add .xls suffix to filename (all Excel versions can write this)
       filename = [filename ".xls"];
+      ext = ".xls";
     endif
   else
     fmode = 'rb';
@@ -290,7 +292,7 @@ function [ xls ] = xlsopen (filename, xwrite=0, reqinterface=[])
     else                            ## ...but for writing, we need more info:
       fid = fopen (filename, 'rb'); ## Check if it exists at all...
       if (fid < 0)                  ## File didn't exist yet. Simply create it
-        printf ("Creating file %s\n", filename);
+##      printf ("Creating file %s\n", filename);
         xwrite = 3;
       else                          ## File exists, but isn't writable => Error
         fclose (fid);  ## Do not forget to close the handle neatly
@@ -362,7 +364,7 @@ function [ xls ] = xlsopen (filename, xwrite=0, reqinterface=[])
       if (ftype != 6)
         ## This message is appended after message from getxlsinterfaces()
         printf ("None.\n");
-        warning ("xlsopen.m: no support for spreadsheet I/O\n");
+        warning ("xlsopen.m: no support for '%s' spreadsheet I/O\n", ext);
       endif
     else
       ## No match between filte type & interface found
